@@ -9,21 +9,18 @@ use std::io;
 #[derive(Debug)]
 pub enum TaskQueueError {
     Io(io::Error),
-    Join,
 }
 
 impl Error for TaskQueueError {
     fn description(&self) -> &str {
         match *self {
             TaskQueueError::Io(ref e) => e.description(),
-            TaskQueueError::Join => "Error on JoinHandle::Error invoke",
         }
     }
 
     fn cause(&self) -> Option<&Error> {
         match *self {
             TaskQueueError::Io(ref e) => Some(e),
-            TaskQueueError::Join => None,
         }
     }
 }
@@ -32,7 +29,6 @@ impl Display for TaskQueueError {
     fn fmt(&self, f: &mut Formatter) -> fmt::Result {
         match *self {
             TaskQueueError::Io(ref err) => write!(f, "IO error: {}", err),
-            TaskQueueError::Join => write!(f, "Join error: {}", self.description()),
         }
     }
 }
